/*
	Define a property (vb.net)
	
	Version: 1.0.1
	Date: 2004-08-04
	Author: Jens Gyldenkrne Clausen - nospam(at)gyros.dk
	URI: <http://gyros.dk/homesite/newproperty.js>
			
	This script is an adjustment of Iain Alexander's script to define a sub routine in vb.net 
	(available at <http://www.wilk4.com/asp4hs/aspdotnet4hs.htm>).
	It is written in Jscript and targeted at Homesite users writing vb.net code. It may also 
	work in other editors capable of using Jscript while editing.
	The script is tested in Homesite 5.2.
	
	The code will create a new property with basic Get/Set routines. It is possible
	to write a comment to the property. If the property is defined as ReadOnly or WriteOnly 
	the generator only prints the appropriate method (Get for ReadOnly, Set for WriteOnly).
	
	The property is printed with divider lines to separate it from the rest of the code. 
	The divider lines can be adjusted using the global preferences right below this comment.
	
	The current version cannot format existing properties (as the Iain Alexander script 
	can). 
	
	The script may be used and modified freely - however, if you make improvements to the script 
	I would be glad to receive a notice.
	
	Happy coding.

*/

// Global preferences
// Divider lines and sizes
var dividerChar = "="
var dividerLength = 70;
var semidividerLength = 12;
var divider = "'" + repeatString(dividerChar, dividerLength - 2) + " \n";
var semidivider = "'" + repeatString(dividerChar, semidividerLength - 2) + " ";


function Main() {
	var app = Application;
	var active = app.ActiveDocument;
	var strText = new String();
	var subAccess;
	var subName;
	var subType;
	var subComments;

	
	subName = app.inputbox("Name your new property", "", "")
	
	
	if (subName !=""){ //begin initial if
	//only ask more questions if the first one is answered
	subAccess = app.inputbox("Property Access: Public, Protected, Private, ReadOnly etc?", "", "Public")
	subType = app.inputbox("Property Type: String, integer, object etc?", "", "String")
	//subCalls   = app.inputbox("What methods/objects does it call?", "", "None")
	subComments = app.inputbox("Comment for this property", "", "")
	
			//write the output
		
		var heading = "Property " + subName + " ";
		
		var strOutput = semidivider + heading + endDivider(dividerLength, semidividerLength + heading.length) +  "\n";

		//conditional output for optional entries
		

		strOutput +=  "' Type:   " + subType +"\n";

		if (subComments !=""){
			strOutput +=  "' Comments:  " + subComments +"\n";
		}
		
		
		
		strOutput +=  divider;
		strOutput +=  subAccess + " Property " + subName + " As " + subType + "\n";
		// Print Get-block, unless we've got a writeonly property
		var rgxWO = /\bWriteOnly\b/i; // Search for the word writeonly, ignore case
		if( !(rgxWO.test(subAccess)) ) {
			strOutput += "\tGet\n\t\t" +  subName + " = _" + subName + "\n\tEnd Get\n";
		}	
		
		// Print Set-block, unless we've got a readonly property
		var rgxRO = /\bReadOnly\b/i; // Search for the word readonly, ignore case
		if( !(rgxRO.test(subAccess)) ) {
			strOutput += "\tSet(ByVal Value As " + subType + ")\n\t\t";
			strOutput +=  "_" + subName + " = Value\n\tEnd Set\n";
		}
				
		// Close property
		strOutput +=  "End Property\n\n";
		strOutput += "Private _" + subName + " As " + subType + "\n";			
		
		strOutput +=  divider;
		
		active.SelText = strOutput;
		
		
	}//end initial if
	}

	// Auxillary functions
	
	// endDivider - return a string of divider chars of a length matching the box
	function endDivider(fullLength, usedLength){
		return repeatString(dividerChar, Math.max(fullLength - usedLength, 2) - 1);
	}

	// repeatString - replicate a string to a given length
	function repeatString(strInput, intCount) {
        var arrTmp = new Array(intCount+1);
        return arrTmp.join(strInput);
	}

	
